==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/parse_citi.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_CITI_PARSE_CITI_HPP_INCLUDED
# define YY_CITI_PARSE_CITI_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int citi_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Float = 259,                   /* Float  */
    Eol = 260,                     /* Eol  */
    DATA = 261,                    /* DATA  */
    VAR = 262,                     /* VAR  */
    NAME = 263,                    /* NAME  */
    Begin = 264,                   /* Begin  */
    End = 265,                     /* End  */
    Version = 266,                 /* Version  */
    Identifier = 267,              /* Identifier  */
    Integer = 268,                 /* Integer  */
    CITIFILE = 269,                /* CITIFILE  */
    VarType = 270,                 /* VarType  */
    SegListBegin = 271,            /* SegListBegin  */
    VarListBegin = 272,            /* VarListBegin  */
    SegListEnd = 273,              /* SegListEnd  */
    VarListEnd = 274,              /* VarListEnd  */
    COMMENT = 275,                 /* COMMENT  */
    CONSTANT = 276,                /* CONSTANT  */
    SEG = 277                      /* SEG  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 75 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"

  char * ident;
  double f;
  int d;
  qucs::vector * v;
  struct citi_package_t * p;
  struct citi_header_t * h;

#line 95 "parse_citi.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE citi_lval;


int citi_parse (void);


#endif /* !YY_CITI_PARSE_CITI_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/parse_citi.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_CITI_PARSE_CITI_HPP_INCLUDED
# define YY_CITI_PARSE_CITI_HPP_INCLUDED
/* Debug traces.  */
#ifndef CITI_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define CITI_DEBUG 1
#  else
#   define CITI_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define CITI_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined CITI_DEBUG */
#if CITI_DEBUG
extern int citi_debug;
#endif

/* Token kinds.  */
#ifndef CITI_TOKENTYPE
# define CITI_TOKENTYPE
  enum citi_tokentype
  {
    CITI_EMPTY = -2,
    CITI_EOF = 0,                  /* "end of file"  */
    CITI_error = 256,              /* error  */
    CITI_UNDEF = 257,              /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Float = 259,                   /* Float  */
    Eol = 260,                     /* Eol  */
    DATA = 261,                    /* DATA  */
    VAR = 262,                     /* VAR  */
    NAME = 263,                    /* NAME  */
    Begin = 264,                   /* Begin  */
    End = 265,                     /* End  */
    Version = 266,                 /* Version  */
    Identifier = 267,              /* Identifier  */
    Integer = 268,                 /* Integer  */
    CITIFILE = 269,                /* CITIFILE  */
    VarType = 270,                 /* VarType  */
    SegListBegin = 271,            /* SegListBegin  */
    VarListBegin = 272,            /* VarListBegin  */
    SegListEnd = 273,              /* SegListEnd  */
    VarListEnd = 274,              /* VarListEnd  */
    COMMENT = 275,                 /* COMMENT  */
    CONSTANT = 276,                /* CONSTANT  */
    SEG = 277                      /* SEG  */
  };
  typedef enum citi_tokentype citi_token_kind_t;
#endif

/* Value type.  */
#if ! defined CITI_STYPE && ! defined CITI_STYPE_IS_DECLARED
union CITI_STYPE
{
#line 75 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"

  char * ident;
  double f;
  int d;
  qucs::vector * v;
  struct citi_package_t * p;
  struct citi_header_t * h;

#line 103 "parse_citi.hpp"

};
typedef union CITI_STYPE CITI_STYPE;
# define CITI_STYPE_IS_TRIVIAL 1
# define CITI_STYPE_IS_DECLARED 1
#endif


extern CITI_STYPE citi_lval;


int citi_parse (void);


#endif /* !YY_CITI_PARSE_CITI_HPP_INCLUDED  */
